#ifndef NT2_INCLUDE_CONSTANTS_SQRT_2O_3_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_SQRT_2O_3_HPP_INCLUDED

#include <nt2/constant/include/constants/sqrt_2o_3.hpp>

#endif
